==> pkg_n3toembed.3.0.1.zip: n3toembed.php <==
<?php
/**
 * @package n3t oEmbed
 * @author Pavel Poles - n3t.cz
 * @copyright (C) 2020 - Pavel Poles - n3t.cz
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Plugin\PluginHelper;
use Embera\Embera;

class plgContentN3tOEmbed extends CMSPlugin
{

  protected $autoloadLanguage = true;

  protected function renderEmbed($article, $url)
  {
    $url = strip_tags($url);

    $params = [];
    $params['https_only'] = !!$this->params->get('https_only', 1);
    $params['fake_responses'] = (int)$this->params->get('responsive', '1');
    $params['responsive'] = !!$this->params->get('responsive', 0);

    if ((int)$this->params->get('maxwidth'))
      $params['maxwidth'] = (int)$this->params->get('maxwidth');
    if ((int)$this->params->get('maxheight'))
      $params['maxheight'] = (int)$this->params->get('maxheight');

    if ($this->params->get('fb_app_id') && $this->params->get('fb_app_secret'))
      $params['access_token'] = $this->params->get('fb_app_id') . '|' . $this->params->get('fb_app_secret');

    jimport('Embera.Embera');
    $embera = new Embera($params);

    $posts = $embera->getUrlData($url);

    ob_start();

    if ($posts) {
      $post = array_shift($posts);
      include PluginHelper::getLayoutPath($this->_type, $this->_name, 'post');
    } else
      include PluginHelper::getLayoutPath($this->_type, $this->_name, 'error');

    return ob_get_clean();
  }

  public function onContentPrepare($context, &$article, $params, $page = 0)
  {
    if (stripos($article->text, '{oembed') === false)
      return;

    preg_match_all('~{oembed\s(.*?)}~i', $article->text, $matches, PREG_SET_ORDER);

    if ($matches) {
      foreach ($matches as $match) {
        $output = $this->renderEmbed($article, $match[1]);
        $article->text = str_replace($match[0], $output, $article->text);
      }
    }
  }

}

==> pkg_n3toembed.3.0.2.zip: n3toembed.php <==
<?php
/**
 * @package n3t oEmbed
 * @author Pavel Poles - n3t.cz
 * @copyright (C) 2020 - Pavel Poles - n3t.cz
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die;

use Joomla\CMS\Cache\Cache;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Plugin\PluginHelper;

use Embera\Embera;

class plgContentN3tOEmbed extends CMSPlugin
{

  protected $autoloadLanguage = true;

  public function __construct($subject, $config)
  {
    parent::__construct($subject, $config);

    if (!!$this->params->get('responsive', 0))
      HTMLHelper::stylesheet('plg_content_n3toembed/responsive.min.css', false, true);
  }

  protected function cacheId($url)
  {
    return md5($url);
  }

  public function renderEmbed($article, $url)
  {
    $params = [];
    $params['https_only'] = !!$this->params->get('https_only', 1);
    $params['fake_responses'] = (int)$this->params->get('fake_responses', '1');
    $params['responsive'] = !!$this->params->get('responsive', 0);

    if ((int)$this->params->get('maxwidth'))
      $params['maxwidth'] = (int)$this->params->get('maxwidth');
    if ((int)$this->params->get('maxheight'))
      $params['maxheight'] = (int)$this->params->get('maxheight');

    if ($this->params->get('fb_app_id') && $this->params->get('fb_app_secret'))
      $params['access_token'] = $this->params->get('fb_app_id') . '|' . $this->params->get('fb_app_secret');

    jimport('Embera.Embera');
    $embera = new Embera($params);

    $posts = $embera->getUrlData($url);

    ob_start();

    if ($posts) {
      $post = array_shift($posts);
      include PluginHelper::getLayoutPath($this->_type, $this->_name, 'post');
    } else
      include PluginHelper::getLayoutPath($this->_type, $this->_name, 'error');

    return ob_get_clean();
  }

  public function onContentPrepare($context, &$article, $params, $page = 0)
  {
    if (stripos($article->text, '{oembed') === false)
      return;

    $cache = Factory::getCache('n3toembed');
    if ($cachetime = $this->params->get('cachetime'))
      $cache->setLifeTime($cachetime);

    preg_match_all('~{oembed\s(.*?)}~i', $article->text, $matches, PREG_SET_ORDER);

    if ($matches) {
      foreach ($matches as $match) {
        $url = strip_tags($match[1]);
        $cacheId = $this->cacheId($url);
        static $outputs = [];

        if (!isset($outputs[$cacheId])) {
          $output = $cache->get([$this, 'renderEmbed'], [$erticle, $url], $cacheId);
          $outputs[$cacheId] = $output;
        }

        $article->text = str_replace($match[0], $outputs[$cacheId], $article->text);
      }
    }
  }

}
